import { render, screen, waitFor } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import React from 'react'
import { Provider } from 'react-redux'
import {
  createMockEcolyoStore,
  mockAnalysisState,
  mockProfileState,
} from 'tests/__mocks__/store'
import ProfileComparator from './ProfileComparator'

const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

const mockGetMonthlyForecast = jest.fn()
jest.mock('services/profileType.service', () => {
  return jest.fn(() => ({
    getMonthlyForecast: mockGetMonthlyForecast,
  }))
})

jest.mock('services/profileTypeEntity.service', () => {
  return jest.fn(() => ({
    getProfileType: jest.fn(),
  }))
})

jest.mock(
  'components/Analysis/ProfileComparator/ProfileComparatorRow',
  () => 'mock-profileComparatorRow'
)

const profileCompleted = { ...mockProfileState, isProfileTypeCompleted: true }
const storeProfileCompleted = createMockEcolyoStore({
  profile: profileCompleted,
  analysis: mockAnalysisState,
})

const performanceIndicator = {
  compareValue: 160.42797399999998,
  percentageVariation: 0.026592126632478563,
  value: 156.161853,
}
const performanceIndicators = [
  {
    compareValue: 203.49,
    percentageVariation: 0.12261044768784712,
    value: 178.54,
  },
  {
    compareValue: 7926.82,
    percentageVariation: 0.020542916327102145,
    value: 7763.98,
  },
  {
    compareValue: 1316.46,
    percentageVariation: -0.0009191316105312541,
    value: 1317.67,
  },
]

describe('AnalysisConsumption component', () => {
  it('should be rendered correctly with profile NOT completed and go to profile button', async () => {
    const storeProfileNotCompleted = createMockEcolyoStore({
      profile: mockProfileState,
      analysis: mockAnalysisState,
    })
    const { container } = render(
      <Provider store={storeProfileNotCompleted}>
        <ProfileComparator
          aggregatedPerformanceIndicator={performanceIndicator}
          performanceIndicators={performanceIndicators}
        />
      </Provider>
    )
    await waitFor(() => null, { container })
    expect(container).toMatchSnapshot()
    expect(screen.getByTestId('goToProfile')).toBeInTheDocument()
    expect(screen.queryByTestId('iconGoToProfile')).not.toBeInTheDocument()
  })

  it('should be rendered correctly with profile completed and go to profile edition on click', async () => {
    const { container } = render(
      <Provider store={storeProfileCompleted}>
        <ProfileComparator
          aggregatedPerformanceIndicator={performanceIndicator}
          performanceIndicators={performanceIndicators}
        />
      </Provider>
    )
    await waitFor(() => null, { container })
    expect(container).toMatchSnapshot()
    const rows = container.querySelectorAll('mock-profilecomparatorrow')
    expect(rows.length).toBe(4)
    expect(screen.getByTestId('iconGoToProfile')).toBeInTheDocument()
    expect(screen.queryByTestId('goToProfile')).not.toBeInTheDocument()
    await userEvent.click(screen.getByTestId('iconGoToProfile'))
    expect(mockedNavigate).toHaveBeenCalledWith('/profileType')
  })
})
