import Button from '@material-ui/core/Button'
import Dialog from '@material-ui/core/Dialog'
import CloseIcon from 'assets/icons/ico/close.svg'
import GasBill from 'assets/icons/visu/onboarding/gas_bill.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import StyledIconButton from 'components/CommonKit/IconButton/StyledIconButton'
import { useI18n } from 'cozy-ui/transpiled/react/providers/I18n'
import React from 'react'

const GrdfModalHint = ({
  open,
  handleCloseClick,
}: {
  open: boolean
  handleCloseClick: () => void
}) => {
  const { t } = useI18n()

  return (
    <Dialog
      open={open}
      disableEscapeKeyDown
      onClose={handleCloseClick}
      aria-labelledby="accessibility-title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id="accessibility-title">
        {t('auth.grdfgrandlyon.accessibility.modalHintsTitle')}
      </div>
      <StyledIconButton
        icon={CloseIcon}
        onClick={handleCloseClick}
        aria-label={t('feedback.accessibility.button_close')}
        className="modal-paper-close-button"
      />
      <div className="hintModal">
        <h1 className="text-20-bold">
          {t('auth.grdfgrandlyon.pceModal.title')}
        </h1>
        <div className="content">
          <div className="bill grdf">
            <StyledIcon icon={GasBill} className="bill" size={180} />
          </div>
          <p
            className="grdfText"
            dangerouslySetInnerHTML={{
              __html: t('auth.grdfgrandlyon.pceModal.txt1'),
            }}
          />
          <Button onClick={handleCloseClick} className="btnPrimary">
            {t('auth.grdfgrandlyon.pceModal.button')}
          </Button>
        </div>
      </div>
    </Dialog>
  )
}

export default GrdfModalHint
