import { render, screen } from '@testing-library/react'
import { FluidType } from 'enums'
import { Dataload } from 'models'
import React from 'react'
import {
  baseDataLoad,
  baseMultiFluidDataLoad,
} from 'tests/__mocks__/chartData.mock'
import DataloadSectionValue from './DataloadSectionValue'

describe('DataloadSectionValue component', () => {
  it('should render correctly', () => {
    const { container } = render(
      <DataloadSectionValue
        dataload={baseDataLoad}
        fluidType={FluidType.ELECTRICITY}
      />
    )
    expect(container).toMatchSnapshot()
  })

  describe('case SingleFluid', () => {
    it('should render with unit when value < 1000', () => {
      render(
        <DataloadSectionValue
          dataload={baseDataLoad}
          fluidType={FluidType.ELECTRICITY}
        />
      )
      expect(screen.getByText('12,00')).toBeInTheDocument()
      expect(screen.getByText('FLUID.ELECTRICITY.UNIT')).toBeInTheDocument()
    })
    it('should render with mega unit when value >= 1000', () => {
      const mockDataLoad: Dataload = { ...baseDataLoad, value: 1000 }
      render(
        <DataloadSectionValue
          dataload={mockDataLoad}
          fluidType={FluidType.ELECTRICITY}
        />
      )
      expect(screen.getByText('1,00')).toBeInTheDocument()
      expect(screen.getByText('FLUID.ELECTRICITY.MEGAUNIT')).toBeInTheDocument()
    })
  })

  describe('case Multifluid', () => {
    it('should render correctly when comparison', () => {
      render(
        <DataloadSectionValue
          dataload={baseMultiFluidDataLoad}
          fluidType={FluidType.MULTIFLUID}
        />
      )
      expect(screen.getByText('12,00')).toBeInTheDocument()
      expect(screen.getByText('FLUID.MULTIFLUID.UNIT')).toBeInTheDocument()
    })
  })
})
