import Button from '@material-ui/core/Button'
import doingIcon from 'assets/icons/ico/selection-doing.svg'
import objectiveIcon from 'assets/icons/ico/selection-objective.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { useI18n } from 'cozy-ui/transpiled/react/providers/I18n'
import React from 'react'
import { useNavigate } from 'react-router-dom'
import './ecogestureEmptyList.scss'

interface EcogestureEmptyListProps {
  setTab: React.Dispatch<React.SetStateAction<number>>
  isObjective: boolean
  isSelectionDone: boolean
  openResetEcogestureModal: () => void
}
const EcogestureEmptyList = ({
  setTab,
  isObjective,
  isSelectionDone,
  openResetEcogestureModal,
}: EcogestureEmptyListProps) => {
  const { t } = useI18n()
  const navigate = useNavigate()
  const objOrDoing = isObjective ? 'obj' : 'doing'
  const isDone = isSelectionDone ? '_done' : ''
  return (
    <div className="ec-empty-container">
      <div className="ec-empty-content">
        <StyledIcon
          className={`icon-big ${
            isObjective ? 'icon-objective' : 'icon-doing'
          }`}
          icon={isObjective ? objectiveIcon : doingIcon}
          size={68}
        />
        <div className="text-16-normal">
          {t(`ecogesture.emptyList.${objOrDoing}1${isDone}`)}
        </div>
        <div className="text-16-normal">
          {t(`ecogesture.emptyList.${objOrDoing}2${isDone}`)}
        </div>
        <div className="buttons">
          <Button onClick={() => setTab(2)} className="btnSecondary">
            {t('ecogesture.emptyList.btn1')}
          </Button>

          {isSelectionDone && (
            <Button onClick={openResetEcogestureModal} className="btnSecondary">
              {t('ecogesture.reset')}
            </Button>
          )}

          {!isSelectionDone && (
            <Button
              onClick={() => {
                navigate('/ecogesture-form')
              }}
              className="btnPrimary"
            >
              {t('ecogesture.emptyList.btn2')}
            </Button>
          )}
        </div>
      </div>
    </div>
  )
}

export default EcogestureEmptyList
