import { render, screen } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import React from 'react'
import EcogestureNotFound from './EcogestureNotFound'

const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

jest.mock('components/Header/Header', () => 'mock-header')
jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Content/Content', () => 'mock-content')

describe('EcogestureNotFound component', () => {
  it('should be rendered correctly', () => {
    const { container } = render(
      <EcogestureNotFound text="test" returnPage="ecogestures" />
    )
    expect(container).toMatchSnapshot()
  })
  it('should click on button and be redirected', async () => {
    render(<EcogestureNotFound text="test" returnPage="ecogestures" />)
    await userEvent.click(screen.getByText('error_page.back'))
    expect(mockedNavigate).toHaveBeenCalledWith('/ecogestures')
  })
})
