import { render, screen } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import TimeStepSelector from 'components/FluidChart/TimeStepSelector/TimeStepSelector'
import { FluidType, TimeStep } from 'enums'
import { DateTime } from 'luxon'
import React from 'react'
import { Provider } from 'react-redux'
import * as chartActions from 'store/chart/chart.slice'
import { createMockEcolyoStore, mockChartState } from 'tests/__mocks__/store'

const setCurrentTimeStepSpy = jest.spyOn(chartActions, 'setCurrentTimeStep')
const setCurrentIndexSpy = jest.spyOn(chartActions, 'setCurrentIndex')

describe('TimeStepSelector component', () => {
  beforeEach(() => {
    jest.clearAllMocks()
  })

  it('should render component properly with 4 timesteps', () => {
    const store = createMockEcolyoStore({
      chart: {
        ...mockChartState,
        currentTimeStep: TimeStep.DAY,
        selectedDate: DateTime.local().setZone('utc', {
          keepLocalTime: true,
        }),
      },
    })
    const { container } = render(
      <Provider store={store}>
        <TimeStepSelector fluidType={FluidType.WATER} />
      </Provider>
    )
    expect(screen.getAllByRole('tab').length).toBe(4)
    expect(container).toMatchSnapshot()
  })

  it('should render component properly with 5 timesteps', () => {
    const store = createMockEcolyoStore({
      chart: {
        ...mockChartState,
        currentTimeStep: TimeStep.DAY,
        selectedDate: DateTime.local().setZone('utc', {
          keepLocalTime: true,
        }),
      },
    })
    render(
      <Provider store={store}>
        <TimeStepSelector fluidType={FluidType.ELECTRICITY} />
      </Provider>
    )
    expect(screen.getAllByRole('tab').length).toBe(5)
  })

  it('should define next TimeStep and dispatch it', async () => {
    const store = createMockEcolyoStore({
      chart: {
        ...mockChartState,
        currentTimeStep: TimeStep.YEAR,
        selectedDate: DateTime.local().setZone('utc', {
          keepLocalTime: true,
        }),
      },
    })
    render(
      <Provider store={store}>
        <TimeStepSelector fluidType={FluidType.WATER} />
      </Provider>
    )
    await userEvent.click(screen.getAllByRole('tab')[2])
    expect(setCurrentTimeStepSpy).toHaveBeenCalledTimes(1)
    expect(setCurrentTimeStepSpy).toHaveBeenCalledWith(TimeStep.MONTH)
    expect(setCurrentIndexSpy).toHaveBeenCalledTimes(1)
  })
})
