import {
  Accordion,
  AccordionDetails,
  AccordionSummary,
} from '@material-ui/core'
import Button from '@material-ui/core/Button'
import chevronDown from 'assets/icons/ico/chevron-down.svg'
import profileIcon from 'assets/icons/ico/profile.svg'
import StyledCard from 'components/CommonKit/Card/StyledCard'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import useExploration from 'components/Hooks/useExploration'
import { useI18n } from 'cozy-ui/transpiled/react/providers/I18n'
import {
  FluidType,
  HousingType,
  IndividualOrCollective,
  OutsideFacingWalls,
  ThreeChoicesAnswer,
  UserExplorationID,
} from 'enums'
import React, { useState } from 'react'
import { useNavigate } from 'react-router-dom'
import { useAppSelector } from 'store/hooks'
import './profileTypeOptions.scss'

const ProfileTypeOptions = () => {
  const { profile, profileType } = useAppSelector(state => state.ecolyo)
  const { t } = useI18n()
  const navigate = useNavigate()
  const [, setValidExploration] = useExploration()
  const [isExpanded, setIsExpanded] = useState<boolean>(false)

  const toggleAccordion = () => {
    if (!isExpanded) {
      setValidExploration(UserExplorationID.EXPLORATION001)
    }
    setIsExpanded(prev => !prev)
  }

  const goToForm = () => {
    navigate('/profileType')
  }

  return (
    <div className="profile-type-root">
      <div className="profile-type-content">
        <div className="head text-16-normal-uppercase">
          {t('profile_type.title_profile')}
        </div>
        {!profile.isProfileTypeCompleted && (
          <StyledCard onClick={goToForm} className="profile-link">
            <StyledIcon className="profile-icon" icon={profileIcon} size={42} />
            <span className="link-label text-16-normal">
              {t('profile_type.read_profile')}
            </span>
          </StyledCard>
        )}
        {profile.isProfileTypeCompleted && (
          <Accordion
            expanded={isExpanded}
            onChange={toggleAccordion}
            classes={{
              root: 'expansion-panel-root',
            }}
          >
            <AccordionSummary
              aria-label={t(
                'profile_type.accessibility.button_toggle_detail_profile'
              )}
              expandIcon={
                <StyledIcon icon={chevronDown} className="accordion-icon" />
              }
              classes={{
                root: 'expansion-panel-summary',
                content: 'expansion-panel-content',
              }}
            >
              <StyledIcon
                className="profile-icon"
                icon={profileIcon}
                size={42}
              />
              <div className="text-16-normal profile-title">
                {t('profile_type.your_profile')}
              </div>
            </AccordionSummary>
            <AccordionDetails
              classes={{
                root: 'expansion-panel-details',
              }}
            >
              <div className="profile-container">
                <div className="fields">
                  <div className="label">
                    {t('profile_type.housing_type.title')}
                  </div>
                  <div className="value">
                    {t(`profile_type.housing_type.${profileType.housingType}`)}
                  </div>
                  {Boolean(profileType.constructionYear) && (
                    <div className="value">
                      {t(
                        `profile_type.construction_year.${
                          'text_' + profileType.constructionYear
                        }`
                      )}
                    </div>
                  )}
                  <div className="value">
                    {profileType.area}
                    {t('profile_type.area.name')}
                  </div>
                  <div className="value">
                    {profileType.occupantsNumber}
                    {profileType.occupantsNumber > 1
                      ? t('profile_type.occupantsNumber.multi')
                      : t('profile_type.occupantsNumber.single')}
                  </div>
                  {profileType.housingType === HousingType.APARTMENT && (
                    <div className="value floor">
                      {t(`profile_type.floor.${profileType.floor}`)}
                    </div>
                  )}
                  <div className="value">
                    {profileType.outsideFacingWalls}
                    {profileType.outsideFacingWalls != OutsideFacingWalls.ONE
                      ? t('profile_type.outside_facing_walls.text.multi')
                      : t('profile_type.outside_facing_walls.text.single')}
                  </div>
                </div>
                <div className="fields">
                  <div className="label">{t('profile_type.heating.title')}</div>
                  <div className="value">
                    {t(`profile_type.heating.${profileType.heating}`)}
                  </div>
                  {profileType.heating ===
                    IndividualOrCollective.INDIVIDUAL && (
                    <>
                      <div className="value">
                        {profileType.warmingFluid == null
                          ? t('profile_type.warming_fluid.no_fluid_text')
                          : t(
                              `profile_type.warming_fluid.${
                                profileType.warmingFluid + '_text'
                              }`
                            )}
                      </div>
                      {(profileType.hasInstalledVentilation ===
                        ThreeChoicesAnswer.YES ||
                        profileType.hasReplacedHeater ===
                          ThreeChoicesAnswer.YES) && (
                        <div className="equipments">
                          <div className="value">
                            {profileType.hasInstalledVentilation ===
                              ThreeChoicesAnswer.YES &&
                              t(`profile_type.ventilation.text`)}
                          </div>
                          <div className="value">
                            {profileType.hasReplacedHeater ===
                              ThreeChoicesAnswer.YES &&
                              t(`profile_type.heater_replacement.text`)}
                          </div>
                        </div>
                      )}
                    </>
                  )}
                </div>
                <div className="fields">
                  <div className="label">
                    {t('profile_type.cold_water.title')}
                  </div>
                  <div className="value">
                    {t(`profile_type.cold_water.${profileType.coldWater}_text`)}
                  </div>
                </div>
                <div className="fields">
                  <div className="label">
                    {t('profile_type.hot_water.title')}
                  </div>
                  <div className="value">
                    {t(`profile_type.hot_water.${profileType.hotWater}`)}
                  </div>
                  <div className="value">
                    {profileType.heating ===
                      IndividualOrCollective.INDIVIDUAL &&
                      (profileType.warmingFluid !== null
                        ? t(
                            `profile_type.hot_water_fluid.${profileType.hotWaterFluid}_text`
                          )
                        : t('profile_type.hot_water_fluid.no_fluid_text'))}
                  </div>
                  {profileType.hotWater ===
                    IndividualOrCollective.INDIVIDUAL && (
                    <div className="value">
                      {t(
                        `profile_type.hot_water_equipment.${profileType.hotWaterEquipment}`
                      )}
                    </div>
                  )}
                </div>
                {profileType.individualInsulationWork.length > 0 && (
                  <div className="fields insulation">
                    <div className="label">
                      {t('profile_type.individual_insulation_work.title')}
                    </div>

                    {profileType.individualInsulationWork.map(work => (
                      <div key={work} className="value">
                        {t(`profile_type.individual_insulation_work.${work}`)}
                      </div>
                    ))}
                  </div>
                )}
                <div className="fields">
                  <div className="label">
                    {t('profile_type.cooking_fluid.title')}
                  </div>
                  <div className="value">
                    {t(
                      `FLUID.${
                        Object.values(FluidType)[profileType.cookingFluid]
                      }.LABEL`
                    )}
                  </div>
                </div>
                <Button
                  aria-label={t(
                    'profile_type.accessibility.button_update_profile'
                  )}
                  onClick={goToForm}
                  className="btnSecondary"
                >
                  {t('profile_type.button_update_profile')}
                </Button>
              </div>
            </AccordionDetails>
          </Accordion>
        )}
      </div>
    </div>
  )
}

export default ProfileTypeOptions
