import {
  ConstructionYear,
  EquipmentType,
  Floor,
  FluidType,
  HotWaterEquipment,
  HotWaterFluid,
  HousingType,
  IndividualInsulationWork,
  IndividualOrCollective,
  OutsideFacingWalls,
  ProfileTypeFormType,
  ThreeChoicesAnswer,
  WarmingType,
} from 'enums'
import { DateTime } from 'luxon'

export interface ProfileType {
  area: string
  coldWater: IndividualOrCollective
  constructionYear: ConstructionYear
  cookingFluid: FluidType
  equipments: EquipmentType[]
  floor: Floor
  hasInstalledVentilation: ThreeChoicesAnswer
  hasReplacedHeater: ThreeChoicesAnswer
  heating: IndividualOrCollective
  hotWater: IndividualOrCollective
  hotWaterEquipment: HotWaterEquipment
  hotWaterFluid: HotWaterFluid | null
  housingType: HousingType
  individualInsulationWork: IndividualInsulationWork[]
  occupantsNumber: number
  outsideFacingWalls: OutsideFacingWalls
  updateDate: DateTime
  warmingFluid: WarmingType | null
}

export type ProfileTypeValues = ProfileType[keyof ProfileType]

export interface MonthlyForecast {
  month: number
  fluidForecast: FluidForecast[]
  totalValue: number
}
export interface FluidForecast {
  fluidType: FluidType
  load: number
  value: number
  detailsMonthlyForecast: DetailsMonthlyForecast
}
export interface DetailsMonthlyForecast {
  heatingConsumption: number | null
  ecsConsumption: number | null
  cookingConsumption: number | null
  electricSpecificConsumption: number | null
  coldWaterConsumption: number | null
}

export interface ProfileTypeAnswer {
  type: ProfileTypeFormType
  attribute: keyof ProfileType
  choices: ProfileTypeValues[]
}
