/* eslint-disable @typescript-eslint/no-explicit-any */
/* eslint-disable @typescript-eslint/no-var-requires */
declare let __SENTRY_DSN__: string

import * as Sentry from '@sentry/react'
import Unsubscribe from 'components/Options/Unsubscribe/Unsubscribe'
import CozyClient, { Client, CozyProvider } from 'cozy-client'
import { isFlagshipApp } from 'cozy-device-helper'
import { WebviewIntentProvider } from 'cozy-intent'
import { I18n, initTranslation } from 'cozy-ui/transpiled/react/providers/I18n'
import schema from 'doctypes'
import { memoize } from 'lodash'
import React from 'react'
import { createRoot } from 'react-dom/client'
import EnvironmentService from 'services/environment.service'
import cozyBar from 'utils/cozyBar'
import logApp from 'utils/logger'
import manifest from '../../../manifest.webapp'
import '../../styles/index.scss'

const getToken = (): string => {
  const search = new URLSearchParams(window.location.search)
  return search.get('token') || ''
}

const setupApp = memoize(() => {
  const publicToken = getToken()
  const container: any = document.querySelector('[role=application]')
  const data = JSON.parse(container.dataset.cozy)
  const protocol = window.location.protocol
  const cozyUrl = `${protocol}//${data.domain}`

  const locale = 'fr'
  const polyglot = initTranslation(locale, lang => require(`locales/${lang}`))

  const client: Client = new CozyClient({
    uri: cozyUrl,
    token: publicToken,
    appMetadata: {
      slug: manifest.name,
      version: manifest.version,
    },
    schema,
  })

  const envService = new EnvironmentService()
  const isLocal = envService.isLocal()
  const development = envService.isDev()

  cozyBar.init({
    appName: data.app.name,
    appEditor: data.app.editor,
    cozyClient: client,
    iconPath: data.app.icon,
    lang: data.locale,
    replaceTitleOnMobile: false,
    appSlug: data.app.slug,
    appNamePrefix: data.app.prefix,
    isInvertedTheme: isFlagshipApp(),
  })

  !isLocal &&
    Sentry.init({
      dsn: __SENTRY_DSN__,
      integrations: [Sentry.browserTracingIntegration()],
      // Set tracesSampleRate to 1.0 to capture 100%
      // of transactions for performance monitoring.
      // We recommend adjusting this value in production
      // Set to 0 for local development
      tracesSampleRate: 1.0,

      // Custom settings below
      release: client.appMetadata.version,
      environment: development ? 'development' : 'production',
      // cast because init is somehow missing dsn property
    } as Sentry.BrowserOptions)

  return { container, client, locale, polyglot }
})

const init = () => {
  const { container, client, locale, polyglot } = setupApp()
  const root = createRoot(container)

  root.render(
    <WebviewIntentProvider setBarContext={cozyBar.setWebviewContext}>
      <CozyProvider client={client}>
        <I18n lang={locale} polyglot={polyglot}>
          <Unsubscribe />
        </I18n>
      </CozyProvider>
    </WebviewIntentProvider>
  )
}

// initial rendering of the application
document.addEventListener('DOMContentLoaded', () => init())
// excludes Chrome, Edge, and all Android browsers that include the Safari name in their user agent
const isSafari = /^((?!chrome|android).)*safari/i.test(navigator.userAgent)
if (!isSafari && 'serviceWorker' in navigator) {
  window.addEventListener('load', function () {
    navigator.serviceWorker
      .register('/serviceWorker.js')
      .then(reg => console.log('service worker registered', reg.scope))
      .catch(error => {
        const errorMessage = `service worker not registered: ${JSON.stringify(
          error
        )}`
        logApp.error(errorMessage)
        Sentry.captureException(errorMessage)
      })
  })
}

if (module.hot) {
  init()
  module.hot.accept()
}
